==> refcodes-cli-3.1.2-sources.jar: org/refcodes/cli/AmbiguousArgsException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.cli;

/**
 * Thrown in case the command line arguments do not match the required syntax.
 */
public class AmbiguousArgsException extends ArgsSyntaxException {

	// /////////////////////////////////////////////////////////////////////////
	// STATICS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTS:
	// /////////////////////////////////////////////////////////////////////////

	private static final long serialVersionUID = 1L;

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new ambiguous args exception.
	 *
	 * @param aArgs the args
	 * @param aMessage The aMessage describing this exception.
	 * @param aErrorCode The error code identifying this exception.
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, String aErrorCode ) {
		super( aArgs, aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new ambiguous args exception.
	 *
	 * @param aArgs the args
	 * @param aMessage The aMessage describing this exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aErrorCode The error code identifying this exception.
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aArgs, aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new ambiguous args exception.
	 *
	 * @param aArgs the args
	 * @param aMessage The aMessage describing this exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, Throwable aCause ) {
		super( aArgs, aMessage, aCause );
	}

	/**
	 * Instantiates a new ambiguous args exception.
	 *
	 * @param aArgs the args
	 * @param aMessage The aMessage describing this exception.
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage ) {
		super( aArgs, aMessage );
	}

	/**
	 * Instantiates a new ambiguous args exception.
	 *
	 * @param aArgs the args
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aErrorCode The error code identifying this exception.
	 */
	public AmbiguousArgsException( String[] aArgs, Throwable aCause, String aErrorCode ) {
		super( aArgs, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new ambiguous args exception.
	 *
	 * @param aArgs the args
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 */
	public AmbiguousArgsException( String[] aArgs, Throwable aCause ) {
		super( aArgs, aCause );
	}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HOOKS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// INNER CLASSES:
	// /////////////////////////////////////////////////////////////////////////
}

==> refcodes-cli-3.2.2-sources.jar: org/refcodes/cli/AmbiguousArgsException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.cli;

/**
 * Thrown in case the command line arguments do not match the required syntax.
 */
public class AmbiguousArgsException extends ArgsSyntaxException {

	// /////////////////////////////////////////////////////////////////////////
	// STATICS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTS:
	// /////////////////////////////////////////////////////////////////////////

	private static final long serialVersionUID = 1L;

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aMessage The aMessage describing this exception.
	 * @param aSource The {@link Term} responsible for this exception (source).
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, Term aSource ) {
		super( aArgs, aMessage, aSource );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aMessage The aMessage describing this exception.
	 * @param aErrorCode The error code identifying this exception.
	 * @param aSource The {@link Term} responsible for this exception (source).
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, String aErrorCode, Term aSource ) {
		super( aArgs, aMessage, aErrorCode, aSource );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aMessage The aMessage describing this exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aSource The {@link Term} responsible for this exception (source).
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, Throwable aCause, Term aSource ) {
		super( aArgs, aMessage, aCause, aSource );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aMessage The aMessage describing this exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aErrorCode The error code identifying this exception.
	 * @param aSource The {@link Term} responsible for this exception (source).
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, Throwable aCause, String aErrorCode, Term aSource ) {
		super( aArgs, aMessage, aCause, aErrorCode, aSource );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aSource The {@link Term} responsible for this exception (source).
	 */
	public AmbiguousArgsException( String[] aArgs, Throwable aCause, Term aSource ) {
		super( aArgs, aCause, aSource );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aErrorCode The error code identifying this exception.
	 * @param aSource The {@link Term} responsible for this exception (source).
	 */
	public AmbiguousArgsException( String[] aArgs, Throwable aCause, String aErrorCode, Term aSource ) {
		super( aArgs, aCause, aErrorCode, aSource );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aMessage The aMessage describing this exception.
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage ) {
		super( aArgs, aMessage );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aMessage The aMessage describing this exception.
	 * @param aErrorCode The error code identifying this exception.
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, String aErrorCode ) {
		super( aArgs, aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aMessage The aMessage describing this exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, Throwable aCause ) {
		super( aArgs, aMessage, aCause );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aMessage The aMessage describing this exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aErrorCode The error code identifying this exception.
	 */
	public AmbiguousArgsException( String[] aArgs, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aArgs, aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 */
	public AmbiguousArgsException( String[] aArgs, Throwable aCause ) {
		super( aArgs, aCause );
	}

	/**
	 * Instantiates a new {@link AmbiguousArgsException} exception.
	 *
	 * @param aArgs The arguments participating in the exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aErrorCode The error code identifying this exception.
	 */
	public AmbiguousArgsException( String[] aArgs, Throwable aCause, String aErrorCode ) {
		super( aArgs, aCause, aErrorCode );
	}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HOOKS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// INNER CLASSES:
	// /////////////////////////////////////////////////////////////////////////
}
